==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/ClassConstant.h <==
// public class org.dellroad.jc.cgen.ClassConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5197568871928cde org_dellroad_jc_cgen_ClassConstant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_ClassConstant_H_
#define _JC_org_dellroad_jc_cgen_ClassConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_StringConstant$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_refs	_jc_org_dellroad_jc_cgen_ClassConstant$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs	_jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$refs	_jc_org_dellroad_jc_cgen_ClassConstant$refs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$nonrefs	_jc_org_dellroad_jc_cgen_ClassConstant$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$object	_jc_org_dellroad_jc_cgen_ClassConstant$object;

typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$fields_struct	_jc_org_dellroad_jc_cgen_ClassConstant$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_ClassConstant$vmethods	_jc_org_dellroad_jc_cgen_ClassConstant$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_ClassConstant$vtable	_jc_org_dellroad_jc_cgen_ClassConstant$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_ClassConstant$vtype	_jc_org_dellroad_jc_cgen_ClassConstant$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_ClassConstant$fields_struct {
	struct _jc_java_lang_String$object	*PREFIX;
};
extern _jc_org_dellroad_jc_cgen_ClassConstant$fields_struct _jc_org_dellroad_jc_cgen_ClassConstant$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_ClassConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_ClassConstant$object *);

// Static methods
extern void _jc_org_dellroad_jc_cgen_ClassConstant$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_ClassConstant$method$getClassName$16caec205f558b60(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
extern jboolean _jc_org_dellroad_jc_cgen_ClassConstant$method$isClassConstant$9cf8fb86570f485f(_jc_env *, struct _jc_soot_jimple_StringConstant$object *);
extern struct _jc_soot_jimple_StringConstant$object *_jc_org_dellroad_jc_cgen_ClassConstant$method$v$892cc6d83e64f7d5(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_ClassConstant$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_ClassConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_ClassConstant$vmethods	org_dellroad_jc_cgen_ClassConstant;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_ClassConstant$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_ClassConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ClassConstant$refs {
    _jc_org_dellroad_jc_cgen_ClassConstant$sub_refs	org_dellroad_jc_cgen_ClassConstant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ClassConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs	org_dellroad_jc_cgen_ClassConstant;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_ClassConstant$object {
	_jc_org_dellroad_jc_cgen_ClassConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_ClassConstant$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_ClassConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_ClassConstant$vtype _jc_org_dellroad_jc_cgen_ClassConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_ClassConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_ClassConstant$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_ClassConstant_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/ClassConstant.h <==
// public class org.dellroad.jc.cgen.ClassConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5197568871928cde org_dellroad_jc_cgen_ClassConstant

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_ClassConstant_H_
#define _JC_org_dellroad_jc_cgen_ClassConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_StringConstant$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_refs	_jc_org_dellroad_jc_cgen_ClassConstant$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs	_jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$refs	_jc_org_dellroad_jc_cgen_ClassConstant$refs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$nonrefs	_jc_org_dellroad_jc_cgen_ClassConstant$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$object	_jc_org_dellroad_jc_cgen_ClassConstant$object;

typedef struct _jc_org_dellroad_jc_cgen_ClassConstant$fields_struct	_jc_org_dellroad_jc_cgen_ClassConstant$fields_struct;
typedef const struct _jc_org_dellroad_jc_cgen_ClassConstant$vmethods	_jc_org_dellroad_jc_cgen_ClassConstant$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_ClassConstant$vtable	_jc_org_dellroad_jc_cgen_ClassConstant$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_ClassConstant$vtype	_jc_org_dellroad_jc_cgen_ClassConstant$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_cgen_ClassConstant$fields_struct {
	struct _jc_java_lang_String$object	*PREFIX;
};
extern _jc_org_dellroad_jc_cgen_ClassConstant$fields_struct _jc_org_dellroad_jc_cgen_ClassConstant$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_cgen_ClassConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_ClassConstant$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_org_dellroad_jc_cgen_ClassConstant$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_cgen_ClassConstant$method$getClassName$16caec205f558b60(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_cgen_ClassConstant$method$isClassConstant$9cf8fb86570f485f(_jc_env *, struct _jc_soot_jimple_StringConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_StringConstant$object *_jc_org_dellroad_jc_cgen_ClassConstant$method$v$892cc6d83e64f7d5(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_ClassConstant$vmethods {
};

// Vtable
struct _jc_org_dellroad_jc_cgen_ClassConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_ClassConstant$vmethods	org_dellroad_jc_cgen_ClassConstant;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_ClassConstant$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_ClassConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ClassConstant$refs {
    _jc_org_dellroad_jc_cgen_ClassConstant$sub_refs	org_dellroad_jc_cgen_ClassConstant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_ClassConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_ClassConstant$sub_nonrefs	org_dellroad_jc_cgen_ClassConstant;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_ClassConstant$object {
	_jc_org_dellroad_jc_cgen_ClassConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_ClassConstant$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_ClassConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_ClassConstant$vtype _jc_org_dellroad_jc_cgen_ClassConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_ClassConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_ClassConstant$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_ClassConstant_H_ */
